==> weather-2.01.tar.bz2: weather/weather.h <==
/***************************************************************************
 *   Weather module for Kadu communicator                                  *
 *   2004 Micha Maek (bysk)                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEATHER_H
#define WEATHER_H

#include <qobject.h>
#include <qlistview.h>
#include <qprogressbar.h>
#include <qtimer.h>
#include <qhbuttongroup.h>
#include <qpopupmenu.h>

#include "config_file.h"
#include "userbox.h"

#include "weather_net.h"

/**
	Okienko wyszukiwania miejscowoci, wykorzystuje klas SearchIDLocation
**/
class WeatherCodeDialog : public QDialog
{
	Q_OBJECT
	
	private:
		SearchIDLocation idSearch;
		QListViewItem* listItem;
		ConfigFile* moduleConfig;
		
		const QStringList& weatherConfigNames;
		const QStringList& weatherConfigFiles;
		QStringList& lastLocList;
		
		QComboBox* c_config;
		QLineEdit* e_id;
		QComboBox* c_name;
		QListView* lv_search;
		QPushButton* b_search;
		QProgressBar* p_linking;
		QPushButton* b_ok;
		QPushButton* b_cancel;
		
		QTimer* timer;
		
		static int config_pos;
		
	private slots:
		void okButton();
		void searchButton();
		void downloadingProgress();
		void searchSelChanged();
		//void c_nameActivated(int);
		
		void downloadingFinished();
		void downloadingError();
		void downloadingRedirected(QString link);
		
	public:
		WeatherCodeDialog(QListViewItem* item, ConfigFile* cf, const QStringList& wCfFiles,
				const QStringList& wCfNames, int actual, QStringList& lastLoc, QWidget* parent = 0);
		~WeatherCodeDialog();
};

/**
	Wywietla w okienku prognoz pogody
	pobran za pomoc klasy GetForecast
**/
class ShowForecastDialog : public QDialog
{
	Q_OBJECT
	
	private:
		Forecast forecast;
		GetForecast downloader;
		
		ConfigFile* moduleConfig;
		
		QVBoxLayout* vlayout;
		QLabel* l_header;
		QLabel* e_message;
		QHButtonGroup* btn_box;
		QProgressBar* p_linking;
		QPopupMenu* contextMenu;
		
		QTimer* timer;
		
		ForecastContener& savedForecast;
		int currentPage;
		
		void showForecast();
		void mousePressEvent(QMouseEvent * e);
		
	private slots:
		void downloadingFinished();
		void downloadingError();
		void downloadingProgress();
		void dayClicked(int id);
		void menuCopy();
		void menuGoToPage();
		
	public:
		ShowForecastDialog(ForecastContener& fl, const QString& configFile, const QString& locID,
								ConfigFile* cf, QWidget* parent = 0);
		~ShowForecastDialog();
};

/**
	Gwna klasa moduu, obsuga menu oraz konfiguracji.
**/
class Weather : public QObject
{
	Q_OBJECT
	
	private:
		ConfigFile* moduleConfig;
		QStringList weatherConfigFiles;
		QStringList weatherConfigNames;
		QStringList lastLocList;
		QTimer* autoDownloadTimer;
		
		ForecastContener savedForecast;
		GetForecast* downloader;
		Forecast forecast;
		
		int menuMyWeather, menuWeatherFor;
		int lastKeepValue;
		bool lastAuto, lastHints, lastDesc;
		
		QString myNick;
		
		QString parse(const ForecastDay& day, QString str);
		
	private slots:
		void PopupMenuCreate();
		void ShowWeather();
		void ShowMyWeather();
		void ShowWeatherFor();
		void CreateConfigDialog();
		void ApplyConfigDialog();
		void EditLocation();
		void ClearLocation();
		void AutoFindLocation();
		void AutoFindAllLocation();
		void changedKeepFor(int value);
		void checkedAutoLoad(bool check);
		void checkedShowHints(bool check);
		void checkedDescription(bool check);
		
		void autoDownload();
		void autoDownloadingFinished();
		
	public:
		Weather();
		~Weather();
};

/**
	Okienko suce do jednorazowego wyszukania miejscowoci
	i wyswietlenia dla niej pogody
**/
class ShowForecastFor : public QDialog
{
	Q_OBJECT

	private:
		SearchIDLocation idSearch;
		
		QComboBox* c_config;
		QComboBox* c_name;
		QPushButton* b_search;
		QPushButton* b_cancel;
		QLabel* l_status;
		
		ConfigFile* moduleConfig;
		ForecastContener& savedForecast;
		const QStringList& weatherConfigNames;
		const QStringList& weatherConfigFiles;
		QStringList& lastLocList;
		
		static int config_pos;
		
	private slots:
		void searchButton(void);
		void downloadingFinished(void);
		void downloadingError(void);
	
	public:
		ShowForecastFor(ConfigFile* cf, ForecastContener& sf, const QStringList& wCfFiles,
			const QStringList& wCfNames, QStringList& lastLoc, QWidget* parent = 0);
		~ShowForecastFor();
};

/**
	Pobiera z katalogu publicznego GG nazw miasta kontaktu
	i prbuje je znale w jednym z serwisw pogodowych (jeli item != 0 w konstruktorze).
	Jeli item == 0 to wykonuje te czynnoci dla caej listy kontaktw.
**/
class AutoFindID : public QDialog
{
	Q_OBJECT
	
	private:
		bool singleItem;
	
		SearchIDLocation idSearch;
		SearchRecord searchRecord;
		QListView* lv_loc;
		QListViewItem* listItem;
		
		const QStringList& weatherConfigFiles;
		const QStringList& weatherConfigNames;
		
		QLabel* l_message;
		QProgressBar* p_linking;
		QPushButton* b_search;
		QPushButton* b_cancel;
		
		int indexOfConfigFile;
		QString altnick;
		QString city;
		
		void nextItem(QListViewItem* item);
		
	private slots:
		void searchButton(void);
		void newSearchResults(SearchResults& searchResults, int seq, int fromUin);
		void downloadingFinished(void);
		void downloadingError(void);
		
	public:
		AutoFindID(QListView* list, ConfigFile* cf, const QStringList& wCfFiles,
				const QStringList& wCfNames, QWidget* parent, QListViewItem* item = 0);
		~AutoFindID();
};

#endif // WEATHER_H

==> weather-2.02.tar.bz2: weather/weather.h <==
/***************************************************************************
 *   Weather module for Kadu communicator                                  *
 *   2004 Micha Maek (bysk)                                             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef WEATHER_H
#define WEATHER_H

#include <qobject.h>
#include <qlistview.h>
#include <qprogressbar.h>
#include <qtimer.h>
#include <qhbuttongroup.h>
#include <qpopupmenu.h>

#include "config_file.h"
#include "userbox.h"

#include "weather_net.h"

/**
	Okienko wyszukiwania miejscowoci, wykorzystuje klas SearchIDLocation
**/
class WeatherCodeDialog : public QDialog
{
	Q_OBJECT
	
	private:
		SearchIDLocation idSearch;
		QListViewItem* listItem;
		ConfigFile* moduleConfig;
		
		const QStringList& weatherConfigNames;
		const QStringList& weatherConfigFiles;
		QStringList& lastLocList;
		
		QComboBox* c_config;
		QLineEdit* e_id;
		QComboBox* c_name;
		QListView* lv_search;
		QPushButton* b_search;
		QProgressBar* p_linking;
		QPushButton* b_ok;
		QPushButton* b_cancel;
		
		QTimer* timer;
		
		static int config_pos;
		
	private slots:
		void okButton();
		void searchButton();
		void downloadingProgress();
		void searchSelChanged();
		//void c_nameActivated(int);
		
		void downloadingFinished();
		void downloadingError(QString url);
		void downloadingRedirected(QString link);
		
	public:
		WeatherCodeDialog(QListViewItem* item, ConfigFile* cf, const QStringList& wCfFiles,
				const QStringList& wCfNames, int actual, QStringList& lastLoc, QWidget* parent = 0);
		~WeatherCodeDialog();
};

/**
	Wywietla w okienku prognoz pogody
	pobran za pomoc klasy GetForecast
**/
class ShowForecastDialog : public QDialog
{
	Q_OBJECT
	
	private:
		Forecast forecast;
		GetForecast downloader;
		
		ConfigFile* moduleConfig;
		
		QVBoxLayout* vlayout;
		QLabel* l_header;
		QLabel* e_message;
		QHButtonGroup* btn_box;
		QProgressBar* p_linking;
		QPopupMenu* contextMenu;
		
		QTimer* timer;
		
		ForecastContener& savedForecast;
		int currentPage;
		
		void showForecast();
		void mousePressEvent(QMouseEvent * e);
		
	private slots:
		void downloadingFinished();
		void downloadingError(int err, QString url);
		void downloadingProgress();
		void dayClicked(int id);
		void menuCopy();
		void menuGoToPage();
		
	public:
		ShowForecastDialog(ForecastContener& fl, const QString& configFile, const QString& locID,
								ConfigFile* cf, QWidget* parent = 0);
		~ShowForecastDialog();
};

/**
	Gwna klasa moduu, obsuga menu oraz konfiguracji.
**/
class Weather : public QObject
{
	Q_OBJECT
	
	private:
		ConfigFile* moduleConfig;
		QStringList weatherConfigFiles;
		QStringList weatherConfigNames;
		QStringList lastLocList;
		QTimer* autoDownloadTimer;
		
		ForecastContener savedForecast;
		GetForecast* downloader;
		Forecast forecast;
		
		int menuMyWeather, menuWeatherFor;
		int lastKeepValue;
		bool lastAuto, lastHints, lastDesc;
		
		QString myNick;
		
		QString parse(const ForecastDay& day, QString str);
		
	private slots:
		void PopupMenuCreate();
		void ShowWeather();
		void ShowMyWeather();
		void ShowWeatherFor();
		void CreateConfigDialog();
		void ApplyConfigDialog();
		void EditLocation();
		void ClearLocation();
		void AutoFindLocation();
		void AutoFindAllLocation();
		void changedKeepFor(int value);
		void checkedAutoLoad(bool check);
		void checkedShowHints(bool check);
		void checkedDescription(bool check);
		
		void autoDownload();
		void autoDownloadingFinished();
		
	public:
		Weather();
		~Weather();
};

/**
	Okienko suce do jednorazowego wyszukania miejscowoci
	i wyswietlenia dla niej pogody
**/
class ShowForecastFor : public QDialog
{
	Q_OBJECT

	private:
		SearchIDLocation idSearch;
		
		QComboBox* c_config;
		QComboBox* c_name;
		QPushButton* b_search;
		QPushButton* b_cancel;
		QLabel* l_status;
		
		ConfigFile* moduleConfig;
		ForecastContener& savedForecast;
		const QStringList& weatherConfigNames;
		const QStringList& weatherConfigFiles;
		QStringList& lastLocList;
		
		static int config_pos;
		
	private slots:
		void searchButton(void);
		void downloadingFinished(void);
		void downloadingError(QString url);
	
	public:
		ShowForecastFor(ConfigFile* cf, ForecastContener& sf, const QStringList& wCfFiles,
			const QStringList& wCfNames, QStringList& lastLoc, QWidget* parent = 0);
		~ShowForecastFor();
};

/**
	Pobiera z katalogu publicznego GG nazw miasta kontaktu
	i prbuje je znale w jednym z serwisw pogodowych (jeli item != 0 w konstruktorze).
	Jeli item == 0 to wykonuje te czynnoci dla caej listy kontaktw.
**/
class AutoFindID : public QDialog
{
	Q_OBJECT
	
	private:
		bool singleItem;
	
		SearchIDLocation idSearch;
		SearchRecord searchRecord;
		QListView* lv_loc;
		QListViewItem* listItem;
		
		const QStringList& weatherConfigFiles;
		const QStringList& weatherConfigNames;
		
		QLabel* l_message;
		QProgressBar* p_linking;
		QPushButton* b_search;
		QPushButton* b_cancel;
		
		int indexOfConfigFile;
		QString altnick;
		QString city;
		
		void nextItem(QListViewItem* item);
		
	private slots:
		void searchButton(void);
		void newSearchResults(SearchResults& searchResults, int seq, int fromUin);
		void downloadingFinished(void);
		void downloadingError(void);
		
	public:
		AutoFindID(QListView* list, ConfigFile* cf, const QStringList& wCfFiles,
				const QStringList& wCfNames, QWidget* parent, QListViewItem* item = 0);
		~AutoFindID();
};

#endif // WEATHER_H
